@@ -1,13 +1,15 @@
-from . import cut
-from .ns_util import ns_path, ns, pre_existing_ns_p
-from ..manifest.man import ssm
-from sys import stderr
-from git import Repo
 from itertools import starmap
-from subprocess import run
-from shutil import rmtree
 from os import utime
 from pathlib import Path
+from shutil import rmtree
+from subprocess import run
+from sys import stderr
+
+from git import Repo
+
+from ..manifest.man import ssm
+from . import cut
+from .ns_util import ns, ns_path, pre_existing_ns_p
 
 __all__ = [
     "clone",
@@ -32,9 +34,7 @@ def clone(url, as_name, wd=ns_path, update_man=True, use_git_mtime=False):
     if use_git_mtime:
         for n in repo.tree().list_traverse():
             filepath = clone_path / n.path
-            unixtime = repo.git.log(
-                "-1", "--format='%at'", "--", n.path
-            ).strip("'")
+            unixtime = repo.git.log("-1", "--format='%at'", "--", n.path).strip("'")
             if not unixtime.isnumeric():
                 raise ValueError(
                     f"git log gave non-numeric timestamp {unixtime} for {n.path}"
@@ -189,6 +189,7 @@ def remote_pull_manifest(specific_domains=None):
     ssm.check_manifest()
     return
 
+
 def copy_static_assets(repo_dir, from_name="static", to_name="site", purge=False):
     static_dir = repo_dir / from_name
     site_dir = repo_dir / to_name
