@@ -1,11 +1,17 @@
 from configparser import ConfigParser
 from pathlib import Path
+
 from ..ns_util import ns, ns_path
 from .emitters import Emitter
 
 __all__ = ["standup"]
 
-def standup(domains_list=None, dry_config=False, verbose=True):
+
+def standup(
+    domains_list: list[str] | None = None,
+    dry_config: bool = False,
+    verbose: bool = False,
+):
     ini_fn = "emitters.ini"
     ini_dir = Path(__file__).parent
     c = ConfigParser()
@@ -16,9 +22,9 @@ def standup(domains_list=None, dry_config=False, verbose=True):
         domains_list = [*ns]
     for domain in c.sections():
         if domain not in domains_list:
-            continue # skip 'DEFAULT' section
+            continue  # skip 'DEFAULT' section
         sect = c[domain]
-        ns_p = (ns_path / domain)
+        ns_p = ns_path / domain
         assert ns_p.exists() and ns_p.is_dir(), f"{ns_p} not found"
         for name, emit_type in sect.items():
             if verbose:
@@ -26,10 +32,15 @@ def standup(domains_list=None, dry_config=False, verbose=True):
             directory = ns_p / name
             e = getattr(Emitter, emit_type).value
             if dry_config:
-                emitter = {"emitter": e, "directory": directory, "name": name, "verbose": verbose}
+                emitter = {
+                    "emitter": e,
+                    "directory": directory,
+                    "name": name,
+                    "verbose": verbose,
+                }
             else:
                 emitter = e(directory=directory, name=name, verbose=verbose)
-            #emitters.setdefault(domain, [])
-            #emitters[domain].append(emitter)
+            # emitters.setdefault(domain, [])
+            # emitters[domain].append(emitter)
             emitters.update({domain: emitter})
     return emitters
